@@ -258,16 +258,16 @@ bool Page::hasTextPage() const
     return d->m_text != nullptr;
 }
 
-RegularAreaRect *Page::wordAt(const NormalizedPoint &p, QString *word) const
+std::unique_ptr<RegularAreaRect> Page::wordAt(const NormalizedPoint &p) const
 {
     if (d->m_text) {
-        return d->m_text->wordAt(p, word);
+        return d->m_text->wordAt(p);
     }
 
     return nullptr;
 }
 
-RegularAreaRect *Page::textArea(TextSelection *selection) const
+std::unique_ptr<RegularAreaRect> Page::textArea(const TextSelection &selection) const
 {
     if (d->m_text) {
         return d->m_text->textArea(selection);
@@ -282,7 +282,7 @@ bool Page::hasObjectRect(double x, double y, double xScale, double yScale) const
         return false;
     }
 
-    for (ObjectRect *rect : m_rects) {
+    for (const ObjectRect *rect : m_rects) {
         if (rect->distanceSqr(x, y, xScale, yScale) < distanceConsideredEqual) {
             return true;
         }
@@ -302,7 +302,7 @@ bool Page::hasHighlights(int s_id) const
         return true;
     }
     // iterate on the highlights list to find an entry by id
-    for (HighlightAreaRect *highlight : m_highlights) {
+    for (const HighlightAreaRect *highlight : m_highlights) {
         if (highlight->s_id == s_id) {
             return true;
         }
@@ -374,9 +374,7 @@ TextEntity::List Page::words(const RegularAreaRect *area, TextPage::TextAreaIncl
     }
 
     for (auto &retI : ret) {
-        const TextEntity *orig = retI;
-        retI = new TextEntity(orig->text(), new Okular::NormalizedRect(orig->transformedArea(d->rotationMatrix())));
-        delete orig;
+        retI = TextEntity(retI.text(), Okular::NormalizedRect(retI.transformedArea(d->rotationMatrix())));
     }
 
     return ret;
@@ -628,16 +626,13 @@ void PagePrivate::setHighlight(int s_id, RegularAreaRect *rect, const QColor &co
     m_page->m_highlights.append(hr);
 }
 
-void PagePrivate::setTextSelections(RegularAreaRect *r, const QColor &color)
+void PagePrivate::setTextSelections(const RegularAreaRect &r, const QColor &color)
 {
     deleteTextSelections();
-    if (r) {
-        HighlightAreaRect *hr = new HighlightAreaRect(r);
-        hr->s_id = -1;
-        hr->color = color;
-        m_textSelections = hr;
-        delete r;
-    }
+    HighlightAreaRect *hr = new HighlightAreaRect(&r);
+    hr->s_id = -1;
+    hr->color = color;
+    m_textSelections = hr;
 }
 
 void Page::setSourceReferences(const QList<SourceRefObjectRect *> &refRects)
