@@ -904,7 +904,7 @@ void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation,
             }
             tmplink = p->action(Poppler::Page::Closing);
             if (tmplink) {
-                page->setPageAction(Okular::Page::Closing, createLinkFromPopplerLink(std::move(tmplink.get())));
+                page->setPageAction(Okular::Page::Closing, createLinkFromPopplerLink(tmplink.get()));
             }
             page->setDuration(p->duration());
             page->setLabel(p->label());
@@ -1185,10 +1185,11 @@ bool PDFGenerator::defaultPageContinuous() const
 {
     Poppler::Document::PageLayout defaultValue = pdfdoc->pageLayout();
 
-    if ((defaultValue == Poppler::Document::OneColumn) || (defaultValue == Poppler::Document::TwoColumnLeft) || (defaultValue == Poppler::Document::TwoColumnRight))
+    if ((defaultValue == Poppler::Document::OneColumn) || (defaultValue == Poppler::Document::TwoColumnLeft) || (defaultValue == Poppler::Document::TwoColumnRight)) {
         return true;
-    else
+    } else {
         return false;
+    }
 }
 
 QAbstractItemModel *PDFGenerator::layersModel() const
