@@ -28,7 +28,7 @@
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KStandardAction>
-#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX) && !defined(Q_OS_HAIKU)
 #include <KStartupInfo>
 #include <KWindowInfo>
 #endif
@@ -289,8 +289,13 @@ Shell::Shell(const QString &serializedOptions)
                 KMessageBox::information(this, i18n("There is already a unique Okular instance running. This instance won't be the unique one."));
             }
         } else {
+            // TODO When porting to KF7 Remove
+            // PID is not unique in containers and "-" in the name violates D-Bus naming conventions.
+            // Was left for compatibility with 3rd-party scripts.
             QString serviceName = QStringLiteral("org.kde.okular-") + QString::number(qApp->applicationPid());
             QDBusConnection::sessionBus().registerService(serviceName);
+
+            QDBusConnection::sessionBus().registerService(ShellUtils::currentProcessDbusName());
         }
         if (ShellUtils::noRaise(serializedOptions)) {
             setAttribute(Qt::WA_ShowWithoutActivating);
@@ -429,6 +434,7 @@ void Shell::openNewlySignedFile(const QString &path, int pageNumber)
 
     const int activeTab = m_tabWidget->currentIndex();
     KParts::ReadWritePart *const activePart = m_tabs[activeTab].part;
+    activePart->closeUrl(false);
     activePart->openUrl(url);
 }
 
@@ -445,7 +451,7 @@ bool Shell::canOpenDocs(int numDocs, int desktop)
         return false;
     }
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX) && !defined(Q_OS_HAIKU)
     const KWindowInfo winfo(window()->effectiveWinId(), NET::WMDesktop);
     if (winfo.desktop() != desktop) {
         return false;
@@ -721,7 +727,7 @@ void Shell::fileOpen()
 
 void Shell::tryRaise(const QString &startupId)
 {
-#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX) && !defined(Q_OS_HAIKU)
     if (KWindowSystem::isPlatformWayland()) {
         KWindowSystem::setCurrentXdgActivationToken(startupId);
     } else if (KWindowSystem::isPlatformX11()) {
